@@ -1,31 +1,22 @@
-# -*- coding: utf-8 -*-
 from logging import getLogger
-from time import time, strftime
+from time import strftime, time
 
 from BTrees.IIBTree import IITreeSet
+from collective.solr.flare import PloneFlare
+from collective.solr.indexer import DefaultAdder, SolrIndexProcessor, boost_values
+from collective.solr.interfaces import (
+    ICheckIndexable,
+    ISolrAddHandler,
+    ISolrConnectionManager,
+    ISolrMaintenanceView,
+)
+from collective.solr.parser import SolrResponse, parse_date_as_datetime, unmarshallers
+from collective.solr.utils import findObjects, prepareData
+from plone.uuid.interfaces import IUUID, IUUIDAware
 from Products.CMFCore.utils import getToolByName
 from Products.Five.browser import BrowserView
-from plone.uuid.interfaces import IUUID, IUUIDAware
+from zope.component import queryAdapter, queryUtility
 from zope.interface import implementer
-from zope.component import queryUtility, queryAdapter
-
-try:
-    from collective.indexing.indexer import getOwnIndexMethod
-except ImportError:
-    getOwnIndexMethod = None
-from collective.solr.indexer import DefaultAdder
-from collective.solr.flare import PloneFlare
-from collective.solr.interfaces import ISolrConnectionManager
-from collective.solr.interfaces import ISolrMaintenanceView
-from collective.solr.interfaces import ISolrAddHandler
-from collective.solr.interfaces import ICheckIndexable
-from collective.solr.indexer import SolrIndexProcessor
-from collective.solr.indexer import boost_values
-from collective.solr.parser import parse_date_as_datetime
-from collective.solr.parser import SolrResponse
-from collective.solr.parser import unmarshallers
-from collective.solr.utils import findObjects
-from collective.solr.utils import prepareData
 
 logger = getLogger("collective.solr.maintenance")
 MAX_ROWS = 1000000000
@@ -39,7 +30,7 @@ except ImportError:
 
 
 def timer(func=time):
-    """ set up a generator returning the elapsed time since the last call """
+    """set up a generator returning the elapsed time since the last call"""
 
     def gen(last=func()):
         while True:
@@ -51,7 +42,7 @@ def timer(func=time):
 
 
 def checkpointIterator(function, interval=100):
-    """ the iterator will call the given function for every nth invocation """
+    """the iterator will call the given function for every nth invocation"""
     counter = 0
     while True:
         counter += 1
@@ -61,10 +52,10 @@ def checkpointIterator(function, interval=100):
 
 
 def notimeout(func):
-    """ decorator to prevent long-running solr tasks from timing out """
+    """decorator to prevent long-running solr tasks from timing out"""
 
     def wrapper(*args, **kw):
-        """ wrapper with random docstring so ttw access still works """
+        """wrapper with random docstring so ttw access still works"""
         manager = queryUtility(ISolrConnectionManager)
         manager.setTimeout(None, lock=True)
         try:
@@ -77,10 +68,10 @@ def notimeout(func):
 
 @implementer(ISolrMaintenanceView)
 class SolrMaintenanceView(BrowserView):
-    """ helper view for indexing all portal content in Solr """
+    """helper view for indexing all portal content in Solr"""
 
     def mklog(self, use_std_log=False):
-        """ helper to prepend a time stamp to the output """
+        """helper to prepend a time stamp to the output"""
         write = self.request.RESPONSE.write
 
         def log(msg, timestamp=True):
@@ -93,7 +84,7 @@ class SolrMaintenanceView(BrowserView):
         return log
 
     def optimize(self):
-        """ optimize solr indexes """
+        """optimize solr indexes"""
         manager = queryUtility(ISolrConnectionManager)
         conn = manager.getConnection()
         conn.setTimeout(None)
@@ -101,7 +92,7 @@ class SolrMaintenanceView(BrowserView):
         return "solr indexes optimized."
 
     def clear(self):
-        """ clear all data from solr, i.e. delete all indexed objects """
+        """clear all data from solr, i.e. delete all indexed objects"""
         manager = queryUtility(ISolrConnectionManager)
         uniqueKey = manager.getSchema().uniqueKey
         conn = manager.getConnection()
@@ -120,8 +111,8 @@ class SolrMaintenanceView(BrowserView):
         idxs=[],
         ignore_exceptions=False,
     ):
-        """ find all contentish objects (meaning all objects derived from one
-            of the catalog mixin classes) and (re)indexes them """
+        """find all contentish objects (meaning all objects derived from one
+        of the catalog mixin classes) and (re)indexes them"""
 
         if ignore_portal_types and only_portal_types:
             raise ValueError(
@@ -180,11 +171,6 @@ class SolrMaintenanceView(BrowserView):
 
         for path, obj in findObjects(self.context):
             if ICheckIndexable(obj)():
-                if getOwnIndexMethod:
-                    if getOwnIndexMethod(obj, "indexObject") is not None:
-                        log("skipping indexing of %r via private method.\n" % obj)
-                        continue
-
                 count += 1
                 if count <= skip:
                     continue
@@ -375,8 +361,8 @@ class SolrMaintenanceView(BrowserView):
         logger.info(msg)
 
     def cleanup(self, batch=1000):
-        """ remove entries from solr that don't have a corresponding Zope
-            object or have a different UID than the real object"""
+        """remove entries from solr that don't have a corresponding Zope
+        object or have a different UID than the real object"""
         manager = queryUtility(ISolrConnectionManager)
         proc = SolrIndexProcessor(manager)
         conn = manager.getConnection()
