@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # http://svn.apache.org/repos/asf/lucene/solr/trunk/client/python/solr.py
 
 # Licensed to the Apache Software Foundation (ASF) under one or more
@@ -28,21 +27,26 @@
 # c.delete('123')
 # c.commit()
 
-from plone.dexterity.utils import safe_unicode
-import six.moves.http_client
+import base64
+import codecs
 import socket
+from copy import deepcopy
+from logging import getLogger
 from xml.etree.cElementTree import fromstring
 from xml.sax.saxutils import escape
-import codecs
-import six.moves.urllib.request
-import six.moves.urllib.parse
-from collective.solr.exceptions import SolrConnectionException
-from collective.solr.parser import SolrSchema
-from collective.solr.utils import getConfig
-from collective.solr.utils import translation_map
 
-from logging import getLogger
 import six
+import six.moves.http_client
+import six.moves.urllib.parse
+import six.moves.urllib.request
+from collective.solr.exceptions import (
+    SolrConnectionException,
+    RepeatableSolrConnectionException,
+)
+from collective.solr.parser import SolrSchema
+from collective.solr.utils import getConfig, translation_map
+from plone.dexterity.utils import safe_unicode
+from requests_toolbelt import MultipartEncoder
 
 logger = getLogger(__name__)
 
@@ -55,7 +59,11 @@ class SolrConnection:
         persistent=True,
         postHeaders={},
         timeout=None,
+        login=None,
+        password=None,
+        manager=None,
     ):
+        self.manager = manager
         self.host = host
         self.solrBase = str(solrBase)
         self.persistent = persistent
@@ -66,27 +74,42 @@ class SolrConnection:
         # a real connection to the server is not opened at this point.
         self.conn = six.moves.http_client.HTTPConnection(self.host, timeout=timeout)
         # self.conn.set_debuglevel(1000000)
+        self.login = login
+        self.auth_headers = {}
+        if login and password:
+            credentials = "{0}:{1}".format(login, password)
+            authorization = base64.b64encode(credentials.encode("ascii"))
+            self.auth_headers["Authorization"] = "Basic {0}".format(
+                authorization.decode("ascii")
+            )
         self.xmlbody = []
         self.xmlheaders = {"Content-Type": "text/xml; charset=utf-8"}
         self.xmlheaders.update(postHeaders)
+        self.xmlheaders.update(self.auth_headers)
         if not self.persistent:
             self.xmlheaders["Connection"] = "close"
         self.formheaders = {
-            "Content-Type": "application/x-www-form-urlencoded; charset=utf-8"
+            "Content-Type": "application/x-www-form-urlencoded; charset=utf-8",
         }
+        self.formheaders.update(self.auth_headers)
         if not self.persistent:
             self.formheaders["Connection"] = "close"
 
     def __str__(self):
+        xmlheaders = deepcopy(self.xmlheaders)
+        if "Authorization" in xmlheaders:
+            xmlheaders["Authorization"] = "Basic ***"
         return (
             "SolrConnection{host=%s, solrBase=%s, persistent=%s, "
-            "postHeaders=%s, reconnects=%s}"
+            "postHeaders=%s, reconnects=%s, login=%s, password=%s}"
             % (
                 self.host,
                 self.solrBase,
                 self.persistent,
-                self.xmlheaders,
+                xmlheaders,
                 self.reconnects,
+                self.login,
+                self.auth_headers and "***" or None,
             )
         )
 
@@ -102,16 +125,23 @@ class SolrConnection:
 
     def __errcheck(self, rsp):
         if rsp.status != 200:
-            ex = SolrConnectionException(rsp.status, rsp.reason)
+            body = None
             try:
-                ex.body = rsp.read()
+                body = rsp.read()
             except:  # noqa
                 pass
-            raise ex
+            if (
+                rsp.status == 500
+                and body is not None
+                and b"Missing initial multi part boundary" in body
+            ):
+                raise RepeatableSolrConnectionException(rsp.status, rsp.reason, body)
+            else:
+                raise SolrConnectionException(rsp.status, rsp.reason, body)
         return rsp
 
     def setTimeout(self, timeout):
-        """ set a timeout value for the currently open connection """
+        """set a timeout value for the currently open connection"""
         logger.debug("setting socket timeout on %r: %s", self, timeout)
         self.conn.timeout = timeout
 
@@ -122,7 +152,7 @@ class SolrConnection:
         return self.doGetOrPost("GET", url, "", headers)
 
     def doGetOrPost(self, method, url, body, headers):
-        if not isinstance(body, six.binary_type):
+        if not isinstance(body, (six.binary_type, MultipartEncoder)):
             body = body.encode("utf-8")
         try:
             self.conn.request(method, url, body, headers)
@@ -151,7 +181,7 @@ class SolrConnection:
         self.xmlbody.append(request)
 
     def flush(self):
-        """ send out the stored requests to solr """
+        """send out the stored requests to solr"""
         count = 0
         responses = []
         for request in self.xmlbody:
@@ -281,6 +311,9 @@ class SolrConnection:
             if isinstance(v, (list, tuple)):  # multi-valued
                 for value in v:
                     lst.append(tmpl % self.escapeVal(value))
+                if not v:
+                    tmpl = '<field name="%s" update="set" null="true"/>'
+                    lst.append(tmpl % (self.escapeKey(f)))
             else:
                 lst.append(tmpl % self.escapeVal(v))
         lst.append("</doc>")
@@ -310,7 +343,7 @@ class SolrConnection:
         logger.debug("aborting %d requests: %r", len(self.xmlbody), self.xmlbody)
         del self.xmlbody[:]
 
-    def search(self, **params):
+    def _search(self, **params):
         request_handler = params.get("request_handler", "select")
         if "request_handler" in params:
             del params["request_handler"]
@@ -328,12 +361,26 @@ class SolrConnection:
                 self.conn.close()
         return response
 
+    def search(self, **params):
+        try:
+            return self._search(**params)
+        except RepeatableSolrConnectionException:
+            # Handle "Missing initial multi part boundary" errors, since
+            # they are also caused by the connection stuck in the thread.
+            # Not fixable by a reconnect, a new connection object has to be made.
+            self.manager.closeConnection()
+            duplicate = self.manager.getConnection()
+            duplicate.reconnects = self.reconnects + 1
+            return duplicate._search(**params)
+
     def getSchema(self):
         schema_url = "%s/admin/file/?file=schema.xml"
         # schema_url = '%s/admin/file/?file=managed-schema'
         logger.debug("getting schema from: %s", schema_url % self.solrBase)
         try:
-            self.conn.request("GET", schema_url % self.solrBase)
+            self.conn.request(
+                "GET", schema_url % self.solrBase, headers=self.auth_headers
+            )
             response = self.conn.getresponse()
         except (
             socket.error,
@@ -343,7 +390,9 @@ class SolrConnection:
         ):
             # see `doPost` method for more info about these exceptions
             self.__reconnect()
-            self.conn.request("GET", schema_url % self.solrBase)
+            self.conn.request(
+                "GET", schema_url % self.solrBase, headers=self.auth_headers
+            )
             response = self.conn.getresponse()
 
         if response.status == 200:
