@@ -1,38 +1,36 @@
-# -*- coding: utf-8 -*-
-from Products.CMFCore.utils import getToolByName
+from unittest import TestCase, skipIf
 
-try:
-    from Products.CMFCore.interfaces import IIndexQueueProcessor
-except ImportError:
-    # Plone < 5.1
-    from collective.indexing.interfaces import IIndexQueueProcessor
-from collective.solr.exceptions import SolrInactiveException
-from collective.solr.interfaces import ISearch
-from collective.solr.interfaces import ISolrConnectionManager
-from collective.solr.interfaces import ISolrIndexQueueProcessor
-from collective.solr.interfaces import IZCMLSolrConnectionConfig
-from collective.solr.mangler import mangleQuery
-from collective.solr.testing import HAS_PAC
-from collective.solr.testing import LEGACY_COLLECTIVE_SOLR_FUNCTIONAL_TESTING
-from collective.solr.tests.utils import fakehttp
-from collective.solr.tests.utils import getData
-from collective.solr.utils import getConfig
-from plone.app.testing import TEST_USER_ID
-from plone.app.testing import setRoles
+from plone.app.testing import TEST_USER_ID, setRoles
+from Products.CMFCore.interfaces import IIndexQueueProcessor
+from Products.CMFCore.utils import getToolByName
 
 # from socket import error
 # from socket import timeout
 # from time import sleep
 from transaction import commit
-from unittest import TestCase
-from zope.component import getGlobalSiteManager
-from zope.component import getUtilitiesFor
-from zope.component import queryUtility
+from zope.component import getGlobalSiteManager, getUtilitiesFor, queryUtility
 from zope.configuration import xmlconfig
 from zope.event import notify
 from zope.lifecycleevent import ObjectModifiedEvent
 
-import unittest
+from collective.solr.exceptions import SolrInactiveException
+from collective.solr.interfaces import (
+    ISearch,
+    ISolrConnectionManager,
+    ISolrIndexQueueProcessor,
+    IZCMLSolrConnectionConfig,
+)
+from collective.solr.mangler import mangleQuery
+from collective.solr.testing import LEGACY_COLLECTIVE_SOLR_FUNCTIONAL_TESTING
+from collective.solr.tests.utils import fakehttp, getData
+from collective.solr.utils import getConfig
+
+try:
+    from Products.CMFPlone import relationhelper  # noqa
+
+    HAS_PLONE6 = True
+except ImportError:
+    HAS_PLONE6 = False
 
 
 class UtilityTests(TestCase):
@@ -116,6 +114,7 @@ class IndexingTests(TestCase):
         self.proc.setHost(active=False)
         commit()
 
+    @skipIf(HAS_PLONE6, "ZServer is gone in Plone 6. Therefore this test does not work")
     def testIndexObject(self):
         output = []
         connection = self.proc.getConnection()
@@ -245,19 +244,10 @@ class SiteSetupTests(TestCase):
     def setUp(self):
         self.portal = self.layer["portal"]
 
-    @unittest.skipIf(HAS_PAC, "Plone 4 Only")
-    def testBrowserResourcesPlone4(self):
-        cssreg = getToolByName(self.portal, "portal_css")
-        self.assertTrue(
-            cssreg.getResource(
-                "++resource++collective.solr.resources/style.css"
-            ).getEnabled()
-        )
-
     def testTranslation(self):
         utrans = getToolByName(self.portal, "translation_service").utranslate
 
         def translate(msg):
             return utrans(msgid=msg, domain="solr")
 
-        self.assertEqual(translate("portal_type"), u"Content type")
+        self.assertEqual(translate("portal_type"), "Content type")
